@@ -23,7 +23,7 @@ pub fn derive_parsable(struc: TokenStream) -> TokenStream {
         }
         let final_gen = quote! {
             impl Parsable for #name {
-                fn parse(data: &mut dyn std::io::Read) -> Result<Self, ()> {
+                fn parse(data: &mut dyn std::io::Read) -> std::io::Result<Self> {
                     Ok(Self{
                         #(#fields_gen),*
                     })
